@@ -37,7 +37,7 @@
 #include <QScreen>
 #include <QTcpServer>
 #include <QTcpSocket>
-#include <QtConcurrent/QtConcurrentRun>
+#include <QThreadPool>
 
 #ifdef KSTATUS
   #include <kstatusnotifieritem.h>
@@ -304,6 +304,8 @@ void MainWindow::initSystemTrayIcon()
   m_systemTrayIconMenu->addAction(m_actionSystemUpgrade);
   m_systemTrayIconMenu->addSeparator();
   m_systemTrayIconMenu->addAction(m_actionOptions);
+  m_actionOptions->setText(m_actionOptions->text().remove(QLatin1String("&")));
+
   m_systemTrayIconMenu->addSeparator();
   m_systemTrayIconMenu->addAction(m_actionAbout);
   m_systemTrayIconMenu->addAction(m_actionExit);
@@ -514,9 +516,9 @@ void MainWindow::doSystemUpgrade()
 
   if (isOctopiBusy()) return;
 
-  if(!SettingsManager::getEnableConfirmationDialogInSysUpgrade())
+  if(SettingsManager::getAlwaysUseTheTerminal() || !SettingsManager::getEnableConfirmationDialogInSysUpgrade())
   {
-    if( (m_checkUpdatesStringList.count() != 0 && m_checkUpdatesStringList.contains(QStringLiteral("pacman"))) ||
+    if( SettingsManager::getAlwaysUseTheTerminal() || (m_checkUpdatesStringList.count() != 0 && m_checkUpdatesStringList.contains(QStringLiteral("pacman"))) ||
         (m_outdatedStringList->count() != 0 && m_outdatedStringList->contains(QStringLiteral("pacman"))) )
     {
       m_systemUpgradeDialog = false;
@@ -1116,7 +1118,7 @@ void MainWindow::refreshAppIcon()
           SIGNAL(directoryChanged(QString)), this, SLOT(refreshAppIcon()));
 
   if (m_outdatedStringList->count() > 0)
-    QtConcurrent::run(UnixCommand::execCommandAsNormalUserExt, ctn_PACMAN_SUP_COMMAND);
+    QThreadPool::globalInstance()->start(new ExecCommandAsNormalUserExtTask());
 }
 
 /*
