@@ -221,7 +221,6 @@ void MainWindow::AURToolSelected()
 
   bool lightPackageFilterConnected = false;
   static QStandardItemModel emptyModel;
-  //if (UnixCommand::getLinuxDistro() != ectn_CHAKRA) savePackageColumnWidths();
   refreshTabInfo(true);
   refreshTabFiles(true);
 
@@ -965,7 +964,9 @@ void MainWindow::buildPackageList()
 
     QModelIndex mi = ui->tvPackages->currentIndex();
     m_packageRepo.setAUROutdatedData(m_foreignPackageList, *m_outdatedAURStringList);
-    std::cout << "Time elapsed after setting AURoutdatedData: " << m_time->elapsed() << " mili seconds." << std::endl;
+
+    if(m_debugInfo)
+      std::cout << "Time elapsed after setting AURoutdatedData: " << m_time->elapsed() << " mili seconds." << std::endl;
 
     ui->tvPackages->setCurrentIndex(mi);
 
@@ -1246,7 +1247,7 @@ void MainWindow::showToolButtonAUR()
     }
     else
     {
-      m_toolButtonAUR->setText(QLatin1Char('(') + QString::number(m_outdatedAURPackagesNameVersion->count()) + QLatin1Char(')'));
+      m_toolButtonAUR->setText(QStringLiteral("(%1)").arg(m_outdatedAURPackagesNameVersion->count()));
       m_toolButtonAUR->setToolTip(
           StrConstants::getNewUpdates(m_outdatedAURPackagesNameVersion->count()));
     }
@@ -1375,7 +1376,7 @@ void MainWindow::refreshStatusBar()
     }
     else
     {
-      m_toolButtonPacman->setText(QLatin1Char('(') + QString::number(m_numberOfOutdatedPackages) + QLatin1Char(')'));
+      m_toolButtonPacman->setText(QStringLiteral("(%1)").arg(m_numberOfOutdatedPackages));
       m_toolButtonPacman->setToolTip(StrConstants::getNewUpdates(m_numberOfOutdatedPackages));
     }
 
