@@ -182,7 +182,6 @@ void OptionsDialog::initialize(){
   {
     removeTabByName(tr("Backend"));
     removeTabByName(tr("Package List"));
-    //removeTabByName(tr("Terminal"));
   }
 
   tabWidget->setCurrentIndex(0);
@@ -198,10 +197,38 @@ void OptionsDialog::initButtonBox(){
  */
 void OptionsDialog::initGeneralTab()
 {
+  connect(cbAlwaysUseTheTerminal, SIGNAL(clicked(bool)), this, SLOT(checkUncheckAlwaysUseTheTerminal()));
+  connect(cbConfirmationDialogInSysUpgrade, SIGNAL(clicked(bool)), this, SLOT(checkUncheckConfirmationDialogInSysUpgrade()));
+  connect(cbEnableInternetCheck, SIGNAL(clicked(bool)), this, SLOT(enableDisableGroupBoxInternetCheck()));
+
+  cbAlwaysUseTheTerminal->setChecked(SettingsManager::getAlwaysUseTheTerminal());
   cbShowPackageNumbersOutput->setChecked(SettingsManager::getShowPackageNumbersOutput());
   cbShowStopTransaction->setChecked(SettingsManager::getShowStopTransaction());
   cbConfirmationDialogInSysUpgrade->setChecked(SettingsManager::getEnableConfirmationDialogInSysUpgrade());
-  cbEnableInternetCheck->setChecked(SettingsManager::getEnableInternetChecking());
+  cbEnableInternetCheck->setChecked(SettingsManager::getEnableInternetChecking());  
+  cbPlayBellSound->setChecked(SettingsManager::getPlayBellSoundOnTerminalPasswordInput());
+  gbInternetChecking->setStyleSheet(QLatin1String("border: 0;"));
+
+  if (SettingsManager::getInternetCheckingDomain().contains(QLatin1String("baidu")))
+  {
+    rbBaidu->setChecked(true);
+  }
+  else
+  {
+    rbGoogle->setChecked(true);
+  }
+}
+
+void OptionsDialog::enableDisableGroupBoxInternetCheck()
+{
+  if (cbEnableInternetCheck->isChecked())
+  {
+    gbInternetChecking->setEnabled(true);
+  }
+  else
+  {
+    gbInternetChecking->setEnabled(false);
+  }
 }
 
 /*
@@ -222,6 +249,7 @@ void OptionsDialog::initPackageListTab()
  */
 void OptionsDialog::initAURTab()
 {
+  cbEditMenu->setEnabled(false);
   cbOverwrite->setChecked(false);
   cbOverwrite->setEnabled(false);
 
@@ -241,6 +269,8 @@ void OptionsDialog::initAURTab()
     connect(bRegister, SIGNAL(clicked()), this, SLOT(onAURRegister()));
     connect(bSelAURBuildDir, SIGNAL(clicked()), this, SLOT(onSelAURBuildDir()));
     connect(bClearAURBuildDir, SIGNAL(clicked()), this, SLOT(onClearAURBuildDir()));
+    connect(cbNoEdit, SIGNAL(clicked()), this, SLOT(onAURNoEdit()));
+    connect(cbEditMenu, SIGNAL(clicked()), this, SLOT(onAUREditMenu()));
 
     aurTools.sort();
     comboAUR->addItems(aurTools);
@@ -267,6 +297,8 @@ void OptionsDialog::initAURTab()
       cbOverwrite->setChecked(SettingsManager::getAUROverwriteParam());
       cbNoConfirm->setChecked(SettingsManager::getAURNoConfirmParam());
       cbNoEdit->setChecked(SettingsManager::getAURNoEditParam());
+      cbEditMenu->setEnabled(true);
+      cbEditMenu->setChecked(SettingsManager::getAUREditMenuParam());
     }
     else if (comboAUR->currentText() == ctn_PARU_TOOL)
     {
@@ -459,6 +491,10 @@ void OptionsDialog::accept()
   }
 
   //Set General...
+  if (cbAlwaysUseTheTerminal->isChecked() != SettingsManager::getAlwaysUseTheTerminal())
+  {
+    SettingsManager::setAlwaysUseTheTerminal(cbAlwaysUseTheTerminal->isChecked());
+  }
   if (cbShowPackageNumbersOutput->isChecked() != SettingsManager::getShowPackageNumbersOutput())
   {
     SettingsManager::setShowPackageNumbersOutput(cbShowPackageNumbersOutput->isChecked());
@@ -475,6 +511,21 @@ void OptionsDialog::accept()
   {
     SettingsManager::setEnableInternetChecking(cbEnableInternetCheck->isChecked());
   }
+  if (cbPlayBellSound->isChecked() != SettingsManager::getPlayBellSoundOnTerminalPasswordInput())
+  {
+    SettingsManager::setPlayBellSoundOnTerminalPasswordInput(cbPlayBellSound->isChecked());
+  }
+  if (cbEnableInternetCheck->isChecked())
+  {
+    if (rbBaidu->isChecked())
+    {
+      SettingsManager::setInternetCheckingDomain(QLatin1String("www.baidu.com"));
+    }
+    else
+    {
+      SettingsManager::setInternetCheckingDomain(QLatin1String("www.google.com"));
+    }
+  }
 
   //Set Package List...
   if (cbUseAlternateRowColor->isChecked() != SettingsManager::getUseAlternateRowColor())
@@ -558,11 +609,6 @@ void OptionsDialog::accept()
       SettingsManager::setAURNoEditParam(cbNoEdit->isChecked());
       AURHasChanged = true;
     }
-    /*if (comboAUR->currentText() == ctn_TRIZEN_TOOL && cbDevel->isChecked() != SettingsManager::getAURDevelParam())
-    {
-      SettingsManager::setAURDevelParam(cbDevel->isChecked());
-      AURHasChanged = true;
-    }*/
     if (comboAUR->currentText() == ctn_TRIZEN_TOOL && cbNoConfirm->isChecked() != SettingsManager::getAURNoConfirmParam())
     {
       SettingsManager::setAURNoConfirmParam(cbNoConfirm->isChecked());
@@ -573,11 +619,6 @@ void OptionsDialog::accept()
       SettingsManager::setAURNoEditParam(cbNoEdit->isChecked());
       AURHasChanged = true;
     }
-    /*if (comboAUR->currentText() == ctn_PIKAUR_TOOL && cbDevel->isChecked() != SettingsManager::getAURDevelParam())
-    {
-      SettingsManager::setAURDevelParam(cbDevel->isChecked());
-      AURHasChanged = true;
-    }*/
     if (comboAUR->currentText() == ctn_PIKAUR_TOOL && cbNoConfirm->isChecked() != SettingsManager::getAURNoConfirmParam())
     {
       SettingsManager::setAURNoConfirmParam(cbNoConfirm->isChecked());
@@ -588,11 +629,6 @@ void OptionsDialog::accept()
       SettingsManager::setAURNoEditParam(cbNoEdit->isChecked());
       AURHasChanged = true;
     }
-    /*if (comboAUR->currentText() == ctn_YAY_TOOL && cbDevel->isChecked() != SettingsManager::getAURDevelParam())
-    {
-      SettingsManager::setAURDevelParam(cbDevel->isChecked());
-      AURHasChanged = true;
-    }*/
     if (comboAUR->currentText() == ctn_YAY_TOOL && cbNoConfirm->isChecked() != SettingsManager::getAURNoConfirmParam())
     {
       SettingsManager::setAURNoConfirmParam(cbNoConfirm->isChecked());
@@ -603,11 +639,11 @@ void OptionsDialog::accept()
       SettingsManager::setAURNoEditParam(cbNoEdit->isChecked());
       AURHasChanged = true;
     }
-    /*if (comboAUR->currentText() == ctn_PARU_TOOL && cbDevel->isChecked() != SettingsManager::getAURDevelParam())
+    if (comboAUR->currentText() == ctn_YAY_TOOL && cbEditMenu->isChecked() != SettingsManager::getAUREditMenuParam())
     {
-      SettingsManager::setAURDevelParam(cbDevel->isChecked());
+      SettingsManager::setAUREditMenuParam(cbEditMenu->isChecked());
       AURHasChanged = true;
-    }*/
+    }
     if (comboAUR->currentText() == ctn_PARU_TOOL && cbNoConfirm->isChecked() != SettingsManager::getAURNoConfirmParam())
     {
       SettingsManager::setAURNoConfirmParam(cbNoConfirm->isChecked());
@@ -859,6 +895,8 @@ void OptionsDialog::selectNever()
  */
 void OptionsDialog::comboAURChanged(const QString &text)
 {
+  cbEditMenu->setEnabled(false);
+
   if (text == ctn_NO_AUR_TOOL)
   {
     cbOverwrite->setChecked(false);
@@ -905,6 +943,7 @@ void OptionsDialog::comboAURChanged(const QString &text)
   }
   else if (text == ctn_YAY_TOOL)
   {
+    cbEditMenu->setEnabled(true);
     cbOverwrite->setEnabled(true);
     cbOverwrite->setChecked(SettingsManager::getAUROverwriteParam());
     cbNoConfirm->setEnabled(true);
@@ -912,6 +951,8 @@ void OptionsDialog::comboAURChanged(const QString &text)
     cbSearchOutdatedAURPackages->setEnabled(true);
     cbNoConfirm->setChecked(SettingsManager::getAURNoConfirmParam());
     cbNoEdit->setChecked(SettingsManager::getAURNoEditParam());
+    cbEditMenu->setChecked(SettingsManager::getAUREditMenuParam());
+
     cbSearchOutdatedAURPackages->setChecked(SettingsManager::getSearchOutdatedAURPackages());
   }
   else if (text == ctn_PARU_TOOL)
@@ -947,6 +988,7 @@ void OptionsDialog::onAURConnect()
 
   if (m_debugInfo) v.turnDebugInfoOn();
   bool logged = v.login();
+
   if(logged)
   {
     //Connection was ok. Let's ask user if he wants to help Octopi project by voting for it
@@ -996,6 +1038,28 @@ void OptionsDialog::onAURRegister()
   QDesktopServices::openUrl(QUrl(QStringLiteral("https://aur.archlinux.org/register/")));
 }
 
+void OptionsDialog::onAURNoEdit()
+{
+  if(cbNoEdit->isChecked())
+  {
+    if (cbEditMenu->isEnabled() && cbEditMenu->isChecked())
+    {
+      cbEditMenu->setChecked(false);
+    }
+  }
+}
+
+void OptionsDialog::onAUREditMenu()
+{
+  if(cbEditMenu->isChecked())
+  {
+    if (cbNoEdit->isChecked())
+    {
+      cbNoEdit->setChecked(false);
+    }
+  }
+}
+
 /*
  * When user tries to modify AUR build directory
  */
@@ -1019,3 +1083,27 @@ void OptionsDialog::onClearAURBuildDir()
     leAURBuildDir->setText(QLatin1String(""));
   }
 }
+
+/*
+ * When user selects this option, let's deselect Confirmation Dialog in Sys Upgrade
+ */
+void OptionsDialog::checkUncheckAlwaysUseTheTerminal()
+{
+  if (cbAlwaysUseTheTerminal->isChecked())
+  {
+    if (cbConfirmationDialogInSysUpgrade->isChecked())
+      cbConfirmationDialogInSysUpgrade->setChecked(false);
+  }
+}
+
+/*
+ * When user selects this option, let's deselect Always use the terminal
+ */
+void OptionsDialog::checkUncheckConfirmationDialogInSysUpgrade()
+{
+  if (cbConfirmationDialogInSysUpgrade->isChecked())
+  {
+    if (cbAlwaysUseTheTerminal->isChecked())
+      cbAlwaysUseTheTerminal->setChecked(false);
+  }
+}
