@@ -458,6 +458,7 @@ QString SettingsManager::getAURTool()
   {
     if (getAURNoConfirmParam()) params += QLatin1String(" --noconfirm ");
     if (getAURNoEditParam()) params += QLatin1String(" --editmenu=false ");
+    if (getAUREditMenuParam()) params += QLatin1String(" --editmenu ");
     if (getAUROverwriteParam()) params += QLatin1String(" --overwrite=\"*\" ");
     ret += params;
   }
@@ -526,6 +527,12 @@ QString SettingsManager::getAURToolName()
   return p_instance.getSYSsettings()->value(ctn_KEY_AUR_TOOL, ctn_NO_AUR_TOOL).toString();
 }
 
+bool SettingsManager::getAlwaysUseTheTerminal()
+{
+  SettingsManager p_instance;
+  return (p_instance.getSYSsettings()->value(ctn_KEY_ALWAYS_USE_THE_TERMINAL, false)).toBool();
+}
+
 /*
  * Tests if AUR is using "--devel" parameter
  */
@@ -556,6 +563,12 @@ bool SettingsManager::getAURNoEditParam()
   return (p_instance.getSYSsettings()->value(ctn_KEY_AUR_NO_EDIT_PARAM, false)).toBool();
 }
 
+bool SettingsManager::getAUREditMenuParam()
+{
+  SettingsManager p_instance;
+  return (p_instance.getSYSsettings()->value(ctn_KEY_AUR_EDITMENU_PARAM, false)).toBool();
+}
+
 QString SettingsManager::getAURBuildDir()
 {
   SettingsManager p_instance;
@@ -621,6 +634,18 @@ bool SettingsManager::getEnableInternetChecking()
   return (p_instance.getSYSsettings()->value(ctn_KEY_ENABLE_INTERNET_CHECKING, true)).toBool();
 }
 
+QString SettingsManager::getInternetCheckingDomain()
+{
+  SettingsManager p_instance;
+  return (p_instance.getSYSsettings()->value(ctn_KEY_INTERNET_CHECKING_DOMAIN, QLatin1String("www.google.com"))).toString();
+}
+
+bool SettingsManager::getPlayBellSoundOnTerminalPasswordInput()
+{
+  SettingsManager p_instance;
+  return (p_instance.getSYSsettings()->value(ctn_KEY_PLAY_BELL_SOUND_ON_TERMINAL_PASSWORD_INPUT, false)).toBool();
+}
+
 int SettingsManager::getConsoleFontSize()
 {
   SettingsManager p_instance;
@@ -943,6 +968,12 @@ void SettingsManager::setAURTool(const QString &newValue)
   instance()->getSYSsettings()->sync();
 }
 
+void SettingsManager::setAlwaysUseTheTerminal(bool newValue)
+{
+  instance()->getSYSsettings()->setValue(ctn_KEY_ALWAYS_USE_THE_TERMINAL, newValue);
+  instance()->getSYSsettings()->sync();
+}
+
 /*
  * Sets if AUR tool will use "--devel" parameter
  */
@@ -970,6 +1001,12 @@ void SettingsManager::setAURNoEditParam(bool newValue)
   instance()->getSYSsettings()->sync();
 }
 
+void SettingsManager::setAUREditMenuParam(bool newValue)
+{
+  instance()->getSYSsettings()->setValue(ctn_KEY_AUR_EDITMENU_PARAM, newValue);
+  instance()->getSYSsettings()->sync();
+}
+
 /*
  * Sets the environment variable BUILDDIR
  */
@@ -1040,6 +1077,12 @@ void SettingsManager::setEnableInternetChecking(bool newValue)
   instance()->getSYSsettings()->sync();
 }
 
+void SettingsManager::setInternetCheckingDomain(const QString &newValue)
+{
+  instance()->getSYSsettings()->setValue(ctn_KEY_INTERNET_CHECKING_DOMAIN, newValue);
+  instance()->getSYSsettings()->sync();
+}
+
 void SettingsManager::setSUTool(const QString &newValue)
 {
   instance()->getSYSsettings()->setValue(ctn_KEY_SU_TOOL, newValue);
@@ -1076,4 +1119,10 @@ void SettingsManager::setTerminalFontPointSize(qreal newValue)
   instance()->getSYSsettings()->sync();
 }
 
+void SettingsManager::setPlayBellSoundOnTerminalPasswordInput(bool newValue)
+{
+  instance()->getSYSsettings()->setValue(ctn_KEY_PLAY_BELL_SOUND_ON_TERMINAL_PASSWORD_INPUT, newValue);
+  instance()->getSYSsettings()->sync();
+}
+
 //Octopi related --------------------------------------------------------------------
