@@ -230,6 +230,8 @@ QByteArray UnixCommand::getAURPackageList(const QString &searchString)
   QStringList sl;
 
   QString tool = Package::getForeignRepositoryToolNameParam();
+  std::cout << "Tool incialmente: " << tool.toLatin1().data() << std::endl;
+
   if (tool.contains(QLatin1String("--noconfirm")))
   {
     tool.remove(QLatin1String("--noconfirm"));
@@ -244,8 +246,14 @@ QByteArray UnixCommand::getAURPackageList(const QString &searchString)
   }
   if (tool.contains(QLatin1String("--editmenu=false")))
   {
-    tool.remove(QLatin1String("--editmenu=false"));
-    sl << QLatin1String("--editmenu=false");
+      tool.remove(QRegularExpression(QLatin1String("--editmenu=false")));
+      sl << QLatin1String("--editmenu=false");
+      tool = tool.trimmed();
+  }
+  if (tool.contains(QLatin1String("--editmenu")))
+  {
+    tool.remove(QLatin1String("--editmenu"));
+    sl << QLatin1String("--editmenu");
     tool = tool.trimmed();
   }
   if (tool.contains(QLatin1String("--noedit")))
@@ -291,6 +299,9 @@ QByteArray UnixCommand::getAURPackageList(const QString &searchString)
       sl << QLatin1String("-Ss");
       sl << searchString;
 
+      //std::cout << "Tool value after: " << tool.toLatin1().data() << std::endl;
+      //std::cout << "Tool params: " << sl.join(QLatin1String(" ")).toLatin1().data() << std::endl;
+
       aur.start(tool, sl);
     }
     else if (Package::getForeignRepositoryToolName() == ctn_CHASER_TOOL)
@@ -343,15 +354,13 @@ QByteArray UnixCommand::getAURPackageList(const QString &searchString)
  */
 QString UnixCommand::getShell()
 {
+  const QString BASH_SHELL = QStringLiteral("/usr/bin/bash");
+
+  if (QFile::exists(BASH_SHELL))
+    return BASH_SHELL;
+
   QProcessEnvironment env = QProcessEnvironment::systemEnvironment();
-  QString shell = env.value(QStringLiteral("SHELL"), QStringLiteral("/bin/bash"));
-
-  QFileInfo fi(shell);
-
-  if (fi.fileName() == QLatin1String("fish"))
-    return QStringLiteral("/bin/bash");
-  else
-    return shell;
+  return env.value(QStringLiteral("SHELL"), QStringLiteral("/usr/bin/bash"));
 }
 
 /*
@@ -652,22 +661,26 @@ bool UnixCommand::hasInternetConnection()
 }
 
 /*
- * Pings google site, to make sure internet is OK
+ * Pings ping.archlinux.org (or google.com, baidu.com if it's down), to make sure internet is OK
  */
 bool UnixCommand::doInternetPingTest()
 {
+  bool result = false;
   QTcpSocket socket;
-  QString hostname = QStringLiteral("www.google.com");
+  QString hostname = QStringLiteral("ping.archlinux.org");
 
   socket.connectToHost(hostname, 80);
   if (socket.waitForConnected(5000))
-    return true;
+    result = true;
   else
   {
-    hostname = QStringLiteral("www.baidu.com");
+    hostname = SettingsManager::getInternetCheckingDomain();
     socket.connectToHost(hostname, 80);
-    return socket.waitForConnected(5000);
+    if (socket.waitForConnected(5000))
+      result = true;
   }
+
+  return result;
 }
 
 /*
